==> VirtualBox-2.2.0-OSE.tar.bz2: VirtualBox-2.2.0_OSE/src/VBox/Additions/WINNT/Graphics/Wine/include/msvcrt/malloc.h <==
/*
 * Heap definitions
 *
 * Copyright 2001 Francois Gouget.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

/*
 * Sun LGPL Disclaimer: For the avoidance of doubt, except that if any license choice
 * other than GPL or LGPL is available it will apply instead, Sun elects to use only
 * the Lesser General Public License version 2.1 (LGPLv2) at this time for any software where
 * a choice of LGPL license versions is made available with the language indicating
 * that LGPLv2 or any later version may be used, or where a choice of which version
 * of the LGPL is applied is otherwise unspecified.
 */
#ifndef __WINE_MALLOC_H
#define __WINE_MALLOC_H
#ifndef __WINE_USE_MSVCRT
#define __WINE_USE_MSVCRT
#endif

/* heap function constants */
#define _HEAPEMPTY    -1
#define _HEAPOK       -2
#define _HEAPBADBEGIN -3
#define _HEAPBADNODE  -4
#define _HEAPEND      -5
#define _HEAPBADPTR   -6

#define _FREEENTRY     0
#define _USEDENTRY     1

#if defined(__x86_64__) && !defined(_WIN64)
#define _WIN64
#endif

#if !defined(_MSC_VER) && !defined(__int64)
# ifdef _WIN64
#   define __int64 long
# else
#   define __int64 long long
# endif
#endif

#ifndef _SIZE_T_DEFINED
#ifdef _WIN64
typedef unsigned __int64 size_t;
#else
typedef unsigned int size_t;
#endif
#define _SIZE_T_DEFINED
#endif

#ifndef _HEAPINFO_DEFINED
#define _HEAPINFO_DEFINED
typedef struct _heapinfo
{
  int*           _pentry;
  size_t _size;
  int            _useflag;
} _HEAPINFO;
#endif /* _HEAPINFO_DEFINED */

extern unsigned int* __p__amblksiz(void);
#define _amblksiz (*__p__amblksiz());

#ifdef __cplusplus
extern "C" {
#endif

void*       _expand(void*,size_t);
int         _heapadd(void*,size_t);
int         _heapchk(void);
int         _heapmin(void);
int         _heapset(unsigned int);
size_t _heapused(size_t*,size_t*);
int         _heapwalk(_HEAPINFO*);
size_t _msize(void*);

void*       calloc(size_t,size_t);
void        free(void*);
void*       malloc(size_t);
void*       realloc(void*,size_t);

void        _aligned_free(void*);
void*       _aligned_malloc(size_t,size_t);
void*       _aligned_offset_malloc(size_t,size_t,size_t);
void*       _aligned_realloc(void*,size_t,size_t);
void*       _aligned_offset_realloc(void*,size_t,size_t,size_t);

size_t _get_sbh_threshold(void);
int _set_sbh_threshold(size_t size);

#ifdef __cplusplus
}
#endif

# ifdef __GNUC__
# define _alloca(x) __builtin_alloca((x))
# define alloca(x) __builtin_alloca((x))
# endif

#endif /* __WINE_MALLOC_H */

==> VirtualBox-3.0.12-OSE.tar.bz2: VirtualBox-3.0.12_OSE/src/VBox/Additions/WINNT/Graphics/Wine/include/msvcrt/malloc.h <==
/*
 * Heap definitions
 *
 * Copyright 2001 Francois Gouget.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

/*
 * Sun LGPL Disclaimer: For the avoidance of doubt, except that if any license choice
 * other than GPL or LGPL is available it will apply instead, Sun elects to use only
 * the Lesser General Public License version 2.1 (LGPLv2) at this time for any software where
 * a choice of LGPL license versions is made available with the language indicating
 * that LGPLv2 or any later version may be used, or where a choice of which version
 * of the LGPL is applied is otherwise unspecified.
 */

#ifndef __WINE_MALLOC_H
#define __WINE_MALLOC_H

#include <crtdefs.h>

/* heap function constants */
#define _HEAPEMPTY    -1
#define _HEAPOK       -2
#define _HEAPBADBEGIN -3
#define _HEAPBADNODE  -4
#define _HEAPEND      -5
#define _HEAPBADPTR   -6

#define _FREEENTRY     0
#define _USEDENTRY     1

#ifndef _HEAPINFO_DEFINED
#define _HEAPINFO_DEFINED
typedef struct _heapinfo
{
  int*           _pentry;
  size_t _size;
  int            _useflag;
} _HEAPINFO;
#endif /* _HEAPINFO_DEFINED */

#ifdef __i386__
extern unsigned int* __cdecl __p__amblksiz(void);
#define _amblksiz (*__p__amblksiz());
#else
extern unsigned int _amblksiz;
#endif

#ifdef __cplusplus
extern "C" {
#endif

void*  __cdecl _expand(void*,size_t);
int    __cdecl _heapadd(void*,size_t);
int    __cdecl _heapchk(void);
int    __cdecl _heapmin(void);
int    __cdecl _heapset(unsigned int);
size_t __cdecl _heapused(size_t*,size_t*);
int    __cdecl _heapwalk(_HEAPINFO*);
size_t __cdecl _msize(void*);

void*  __cdecl calloc(size_t,size_t);
void   __cdecl free(void*);
void*  __cdecl malloc(size_t);
void*  __cdecl realloc(void*,size_t);

void   __cdecl _aligned_free(void*);
void*  __cdecl _aligned_malloc(size_t,size_t);
void*  __cdecl _aligned_offset_malloc(size_t,size_t,size_t);
void*  __cdecl _aligned_realloc(void*,size_t,size_t);
void*  __cdecl _aligned_offset_realloc(void*,size_t,size_t,size_t);

size_t __cdecl _get_sbh_threshold(void);
int    __cdecl _set_sbh_threshold(size_t size);

#ifdef __cplusplus
}
#endif

# ifdef __GNUC__
# define _alloca(x) __builtin_alloca((x))
# define alloca(x) __builtin_alloca((x))
# endif

#endif /* __WINE_MALLOC_H */
